@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2019 Alexander Mikhaylenko <exalm7659@gmail.com>
  *
- * SPDX-License-Identifier: LGPL-2.1-or-later
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 #include <handy.h>
@@ -17,8 +17,8 @@ test_hdy_swipe_group_add_remove (void)
 
   group = hdy_swipe_group_new ();
 
-  swipeable1 = g_object_ref_sink (HDY_SWIPEABLE (hdy_carousel_new ()));
-  swipeable2 = g_object_ref_sink (HDY_SWIPEABLE (hdy_carousel_new ()));
+  swipeable1 = HDY_SWIPEABLE (hdy_carousel_new ());
+  swipeable2 = HDY_SWIPEABLE (hdy_carousel_new ());
 
   g_assert_cmpint (g_slist_length (hdy_swipe_group_get_swipeables (group)), ==, 0);
 
